# Table of Contents

- [ai-governance-and-adoption-plan-transformations](<./ai-governance-and-adoption-plan-transformations.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Step 5: Create AI-Related Transformations](<./Step-5-Create-AI-Related-Transformations.md>)
